local AddonData, PrivateTable = ...

if WatchForDamage then
	print ("WatchForDamage already loaded")
	return
end

WatchForDamage = {
	version=AddonData.toc.Version
}
local function L(x) return Translations.WatchForDamage.L(x) end

function WatchForDamage.printVersion()
	LibVersionCheck.register("WatchForDamage", WatchForDamage.version)
	print(L("WatchForDamage Version ") .. (WatchForDamage.version) .. L(" installed!"))
end

local function slashHandler(h, args)
	local r = {}
	local numargs = 1
	local inquote = false
	local token, tmptoken
	for token in string.gmatch(args, "[^%s]+") do
		if token:sub(1, 1) == "\"" then
			tmptoken=""
			token=token:sub(2) -- handle "abc" case
			inquote=true
		end
		if inquote then
			if token:sub(-1) == "\"" then
				inquote=false
				token=token:sub(1, -2)
				token=tmptoken .. token
			else
				tmptoken=tmptoken .. token .. " "
			end
		end
		if not inquote then
			r[numargs] = token
			numargs=numargs+1
		end
	end
	if numargs>1 then
		if r[1] == "version" then
			WatchForDamage.printVersion()
		elseif r[1] == "reset" then
			watchedDamageTypes={}
			print(L("Not watching for anything now."))
		else
			if not watchedDamageTypes then watchedDamageTypes={} end
			watchedDamageTypes[r[1]]=true
			print(L("Watching for damage type: '")..r[1].."'")
		end
	else
		print(L("Usage") .. ": /WatchForDamage version | reset | <damage type>")
	end
end

local function addonLoaded(handle, addon) 
	if (addon == "WatchForDamage") then
		WatchForDamage.printVersion()
		watchedDamageTypes={}
	end
end

local function WatchForDamage(info, val)
	if not info.abilityName or not watchedDamageTypes[info.abilityName] then return end
	local on=L("unknown")
	if info and info.targetName then on=info.targetName end
	local by=L("unknown")
	if info and info.casterName then by=info.casterName end
	print (val .. L(" on ")..on..L(" by ")..by..L(" using ")..info.abilityName)
end

local function damage(h, info)
	if not info.damage then return end
	WatchForDamage(info, info.damage+(info.overkill or 0))
end

local function heal(h, info)
	if not info.heal then return end
	WatchForDamage(info, info.heal+(info.overheal or 0))
end

Command.Event.Attach(Command.Slash.Register("wfd"), slashHandler,"Command.Slash.Register")
Command.Event.Attach(Event.Combat.Damage,   		damage, 	 "Damage")
Command.Event.Attach(Event.Combat.Heal,   		    heal,	 	 "Heal")
Command.Event.Attach(Event.Addon.Load.End, 		    addonLoaded, "AddonLoaded" )
